# 🌐 QGIS

🌐 an AI terraform for [QGIS](https://www.qgis.org/).

```bash
pip install blue-geo
```

```bash
 > QGIS help
QGIS seed [screen]
 . seed 🌱 QGIS.
QGIS expressions pull
 . pull QGIS expressions.
QGIS expressions push [push]
 . push QGIS expressions.
 📂 /Users/kamangir/Library/Application Support/QGIS/QGIS3/profiles/default/python/expressions
 📂 /Users/kamangir/git/blue-geo/blue_geo/QGIS/expressions
QGIS serve[r] [start]
 . start QGIS server.
```

to terraform QGIS, generate the seed 🌱,

```bash
QGIS seed
```

and paste it in the Python Console in QGIS.

![image](https://github.com/kamangir/assets/blob/main/blue-geo/QGIS-python-console.png?raw=true)

![image](https://raw.githubusercontent.com/kamangir/assets/main/blue-geo/QGIS.png)